@@ -1,5 +1,5 @@
-#ifndef BSTS_SRC_STATE_SPACE_STUDENT_MODEL_MANAGER_H_
-#define BSTS_SRC_STATE_SPACE_STUDENT_MODEL_MANAGER_H_
+#ifndef ANALYSIS_COMMON_R_BSTS_SRC_STATE_SPACE_STUDENT_MODEL_MANAGER_H_
+#define ANALYSIS_COMMON_R_BSTS_SRC_STATE_SPACE_STUDENT_MODEL_MANAGER_H_
 
 #include "model_manager.h"
 #include "Models/StateSpace/StateSpaceStudentRegressionModel.hpp"
@@ -45,4 +45,4 @@ class StateSpaceStudentModelManager
 }  // namespace bsts
 }  // namespace BOOM
 
-#endif  // BSTS_SRC_STATE_SPACE_STUDENT_MODEL_MANAGER_H_
+#endif  // ANALYSIS_COMMON_R_BSTS_SRC_STATE_SPACE_STUDENT_MODEL_MANAGER_H_
